# DASIFO

We are working on this project ...
We are looking to create a python library that will regroups:
 - all kind of Databases connections (SQL, NOSQL).
 - it provides some tutorials of APIs: for example conneting to google Drive, cloud....
 - machine learning!
 - deep learning!
 - artificial intelligence!

## We install our library 'dasifo'
```
Make sure you are on the right python's envirement variable. To install it locally, run this line in your terminal
    cd dasifo && python3 setup.py sdist bdist_wheel && pip3 install -e .
```

## Support & Questions:
```
    Drop a message via mohamed.laroussi.1@esprit.tn
```